@@ -5,7 +5,7 @@ class aon:
 	k=0
 	def make(self,path):
 	
-		empty('tempo.py')
+		self.empty('tempo.py')
 		file=open(path,'r')
 		content=file.read()
 	
@@ -17,7 +17,7 @@ class aon:
 	def load(self):
 		if self.k==0:
 			self.k=self.k+1
-			load()
+			self.load()
 		else:
 			self.k=0
 			t=tempo.tempo
